==> projectx-sdk-1.0.58-sources.jar: cn/com/duiba/projectx/sdk/component/task/dto/TaskResult.java <==
package cn.com.duiba.projectx.sdk.component.task.dto;

import cn.com.duiba.projectx.sdk.component.sendprize.dto.SendPrizeResult;

import java.util.List;

public class TaskResult {

    /**
     * 当前时间戳
     */
    private Long timestamp = System.currentTimeMillis();

    /**
     * 是否已经发奖
     */
    private Boolean sendPrize;

    /**
     * 本次分享得到的奖品
     */
    private List<SendPrizeResult> options;

    /**
     * 扩展字段
     */
    private String extra;

    /**
     * 任务ID
     */
    private Integer id;

    /**
     * 任务标识
     */
    private String code;

    /**
     * 任务描述
     */
    private String desc;

    /**
     * 任务图标
     */
    private String icon;

    /**
     * 按钮文案
     */
    private String buttonText;

    public Long getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(Long timestamp) {
        this.timestamp = timestamp;
    }

    public Boolean getSendPrize() {
        return sendPrize;
    }

    public void setSendPrize(Boolean sendPrize) {
        this.sendPrize = sendPrize;
    }

    public List<SendPrizeResult> getOptions() {
        return options;
    }

    public void setOptions(List<SendPrizeResult> options) {
        this.options = options;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public String getButtonText() {
        return buttonText;
    }

    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }
}

==> projectx-sdk-1.0.72-sources.jar: cn/com/duiba/projectx/sdk/component/task/dto/TaskResult.java <==
package cn.com.duiba.projectx.sdk.component.task.dto;

import cn.com.duiba.projectx.sdk.component.sendprize.dto.SendPrizeResult;

import java.util.List;

public class TaskResult {

    /**
     * 当前时间戳
     */
    private Long timestamp = System.currentTimeMillis();

    /**
     * 是否已经发奖
     */
    private Boolean sendPrize;

    /**
     * 本次分享得到的奖品
     */
    private List<SendPrizeResult> options;

    /**
     * 扩展字段
     */
    private String extra;

    /**
     * 任务ID
     */
    private String id;

    /**
     * 任务标题
     */
    private String title;

    /**
     * 任务标识
     */
    private String code;

    /**
     * 任务描述
     */
    private String desc;

    /**
     * 任务图标
     */
    private String icon;

    /**
     * 按钮文案
     */
    private String buttonText;

    /**
     * 领奖Code
     */
    private String prizePendingCode;

    public Long getTimestamp() {
        return timestamp;
    }

    public void setTimestamp(Long timestamp) {
        this.timestamp = timestamp;
    }

    public Boolean getSendPrize() {
        return sendPrize;
    }

    public void setSendPrize(Boolean sendPrize) {
        this.sendPrize = sendPrize;
    }

    public List<SendPrizeResult> getOptions() {
        return options;
    }

    public void setOptions(List<SendPrizeResult> options) {
        this.options = options;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public String getButtonText() {
        return buttonText;
    }

    public void setButtonText(String buttonText) {
        this.buttonText = buttonText;
    }

    public String getPrizePendingCode() {
        return prizePendingCode;
    }

    public void setPrizePendingCode(String prizePendingCode) {
        this.prizePendingCode = prizePendingCode;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }
}
